# ejabberd-extauth

ejabberd-extauth is a library for writing scripts that support
[ejabberd's external authentication mechanism](https://docs.ejabberd.im/developer/guide/#external-authentication).

## How to implement an extauth script

While documentation is still missing, you can find examples here:

* [extauth script for OIDC Password Grant Flow](https://codeberg.org/Natureshadow/ejabberd-extauth-oidc-password)
